@@ -58,7 +58,7 @@ UrlLoader::UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url
     m_request(req),
     m_view(view),
     m_trustedSource(trustedSource),
-    m_protocolAllowsReading(KProtocolManager::supportsReading(m_url) || !KProtocolInfo::isKnownProtocol(m_url)), // If the protocol is unknown, assume it allows reading
+    m_protocolAllowsReading(KProtocolManager::supportsReading(m_url)), // If the protocol is unknown, assume it doesn't allow reading
     m_useDownloadJob(req.browserArgs.downloadJob()),
     m_downloadJob(req.browserArgs.downloadJob()),
     m_allowedActions{m_request.urlActions()}
@@ -98,6 +98,10 @@ void UrlLoader::updateAllowedActions()
         }
     }
 
+    if (!m_protocolAllowsReading && !isMimeTypeKnown(m_mimeType) && m_allowedActions.isAllowed(Konq::UrlAction::Open)) {
+        m_allowedActions.force(Konq::UrlAction::Open);
+    }
+
     if (serviceIsKonqueror(m_service)) {
         m_allowedActions.allow(UrlAction::Open, false);
     }
@@ -199,8 +203,8 @@ void UrlLoader::decideAction()
     if (isMimeTypeKnown(m_mimeType)) {
         m_part = findEmbeddingPart();
         findService();
-        updateAllowedActions();
     }
+    updateAllowedActions();
 
     decideExecute();
     switch (m_request.chosenAction) {
@@ -741,6 +745,22 @@ void UrlLoader::embed()
     }
 }
 
+QString UrlLoader::startingSaveDir() const
+{
+    QString startDir = m_mainWindow->saveDir();
+    if (!startDir.isEmpty()) {
+        return startDir;
+    }
+
+    //TODO find a way to store the last save directory without using properties
+    QString lastSaveDir = m_mainWindow->property(s_lastSaveDirProperty).toString();
+    if (!lastSaveDir.isEmpty()) {
+        return lastSaveDir;
+    } else {
+        return QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
+    }
+}
+
 void UrlLoader::save()
 {
     QFileDialog dlg(m_mainWindow);
@@ -749,14 +769,17 @@ void UrlLoader::save()
     dlg.setOption(QFileDialog::DontConfirmOverwrite, false);
     QString suggestedName = !m_request.suggestedFileName.isEmpty() ? m_request.suggestedFileName : m_url.fileName();
     dlg.selectFile(suggestedName);
-    dlg.setDirectory(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation));
+    dlg.setDirectory(startingSaveDir());
+
     //NOTE: we can't use QDialog::open() because the dialog needs to be synchronous so that we can call
     //DownloadJob::setDownloadPath()
     if (dlg.exec() == QDialog::Rejected) {
         done();
         return;
     }
-    performSave(m_url, dlg.selectedUrls().value(0));
+    QUrl chosenUrl = dlg.selectedUrls().value(0);
+    m_mainWindow->setProperty(s_lastSaveDirProperty, QFileInfo(chosenUrl.path()).absoluteDir().path());
+    performSave(m_url, chosenUrl);
 }
 
 void UrlLoader::performSave(const QUrl& orig, const QUrl& dest)
@@ -810,13 +833,19 @@ void UrlLoader::open()
     }
 
     KJob *job = nullptr;
-    KIO::ApplicationLauncherJob *j = new KIO::ApplicationLauncherJob(m_service);
-    j->setUrls({m_url});
-    j->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
-    if (m_request.tempFile) {
-        j->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+    if (m_service) {
+        KIO::ApplicationLauncherJob *j = new KIO::ApplicationLauncherJob(m_service);
+        j->setUrls({m_url});
+        if (m_request.tempFile) {
+            j->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+        }
+        job = j;
+    } else {
+        KIO::OpenUrlJob *j = new KIO::OpenUrlJob(m_url, m_mimeType);
+        j->setRunExecutables(false);
+        job = j;
     }
-    job = j;
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
     connect(job, &KJob::finished, this, [this, job](){done(job);});
     job->start();
 }
