@@ -25,7 +25,7 @@
 #include "webengineview.h"
 #include "webenginepage.h"
 #include "websslinfo.h"
-#include "webenginewallet.h"
+#include "wallet/webenginewallet.h"
 #include "schemehandlers/errorschemehandler.h"
 #include "webengineurlrequestinterceptor.h"
 #include "spellcheckermanager.h"
@@ -92,8 +92,7 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_statusBarWalletLabel(nullptr),
              m_searchBar(nullptr),
              m_passwordBar(nullptr),
-             m_wallet(nullptr),
-             m_downloader(new WebEngineDownloaderExtension(this))
+             m_wallet(nullptr)
 {
     if (!WebEnginePartControls::self()->isReady()) {
         WebEnginePartControls::self()->setup(KonqWebEnginePart::Profile::defaultProfile());
@@ -120,7 +119,6 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     new WebEngineTextExtension(this);
     new WebEngineHtmlExtension(this);
 
-
     // Layout the GUI...
     QVBoxLayout* l = new QVBoxLayout(mainWidget);
     l->setContentsMargins(0, 0, 0, 0);
@@ -779,9 +777,11 @@ void WebEnginePart::slotShowWalletMenu()
             menu->addAction(a);
         }
     };
+    addAction("walletRescan");
+    menu->addSeparator();
+
     addAction("walletFillFormsNow");
     addAction("walletCacheFormsNow");
-
     addAction("walletCustomizeFields");
     addAction("walletRemoveCustomization");
     menu->addSeparator();
@@ -904,14 +904,17 @@ void WebEnginePart::deleteFeaturePermissionBar(FeaturePermissionBar *bar)
 
 void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& url)
 {
-    if (WebEngineSettings::self()->isNonPasswordStorableSite(url.host()))
+    if (WebEngineSettings::self()->isNonPasswordStorableSite(url.host())) {
         return;
+    }
 
-    if (!WebEngineSettings::self()->askToSaveSitePassword())
+    if (!WebEngineSettings::self()->askToSaveSitePassword()) {
         return;
+    }
 
-    if (m_passwordBar && m_passwordBar->isVisible())
+    if (m_passwordBar && m_passwordBar->isVisible()) {
         return;
+    }
 
     if (!m_passwordBar) {
         m_passwordBar = new PasswordBar(widget());
@@ -1007,6 +1010,10 @@ void WebEnginePart::createWalletActions()
     actionCollection()->setDefaultShortcut(a, QKeySequence("Ctrl+Shift+V"));
     connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
 
+    a = new QAction(i18nc("Scans again the page to detect forms to fill", "Look Again for Forms"), this);
+    actionCollection()->addAction("walletRescan", a);
+    connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
+
     a = new QAction(i18n("&Memorize Passwords in This Page Now"), this);
     actionCollection()->addAction("walletCacheFormsNow", a);
     connect(a, &QAction::triggered, this, [this]{if (page() && m_wallet){m_wallet->savePageDataNow(page());}});
@@ -1043,6 +1050,7 @@ void WebEnginePart::updateWalletActions()
     bool enableCaching = m_webView && !WebEngineSettings::self()->isNonPasswordStorableSite(m_webView->url().host());
     bool hasCustomForms = m_wallet && m_wallet->hasCustomizedCacheableForms(url());
     actionCollection()->action("walletFillFormsNow")->setEnabled(enableCaching && m_wallet && m_walletData.hasCachedData);
+    actionCollection()->action("walletRescan")->setEnabled(enableCaching && m_wallet && m_walletData.hasCachedData);
     actionCollection()->action("walletCacheFormsNow")->setEnabled(enableCaching && m_wallet && (m_walletData.hasAutoFillableForms || hasCustomForms));
     actionCollection()->action("walletCustomizeFields")->setEnabled(enableCaching && m_walletData.hasForms);
     actionCollection()->action("walletRemoveCustomization")->setEnabled(hasCustomForms);
@@ -1112,17 +1120,26 @@ BrowserExtension *WebEnginePart::browserExtension() const
     return findChild<BrowserExtension *>();
 }
 
-void WebEnginePart::displayActOnDownloadedFileBar(KonqInterfaces::DownloaderJob* job)
+void WebEnginePart::displayActOnDownloadedFileBar(KonqInterfaces::DownloadJob* job)
 {
-    if (job->error() != 0) {
+    if (job->error() != 0 || job->intent() != KonqInterfaces::DownloadJob::Save) {
         return;
     }
+
+    //If called in response to the "Save As..." menu entry, the file will be automatically
+    //displayed, so there's no need to show the bar
+    WebEngineDownloadJob *webEngineJob = qobject_cast<WebEngineDownloadJob*>(job);
+    if (webEngineJob && webEngineJob->calledForSaveAs()) {
+        return;
+    }
+
     if (m_actOnDownloadedFileWidget) {
         widget()->layout()->removeWidget(m_actOnDownloadedFileWidget);
         m_actOnDownloadedFileWidget->hide();
         m_actOnDownloadedFileWidget->deleteLater();
         m_actOnDownloadedFileWidget = nullptr;
     }
+
     m_actOnDownloadedFileWidget = new ActOnDownloadedFileBar(job->url(), QUrl::fromLocalFile(job->downloadPath()), this);
     auto deleteWidget = [this] {
         if (!m_actOnDownloadedFileWidget) {
